@@ -3,7 +3,6 @@
 module Projects
   module Settings
     class OperationsController < Projects::ApplicationController
-      before_action :check_license
       before_action :authorize_update_environment!
 
       helper_method :error_tracking_setting
@@ -14,16 +13,37 @@ module Projects
       def update
         result = ::Projects::Operations::UpdateService.new(project, current_user, update_params).execute
 
-        if result[:status] == :success
-          flash[:notice] = _('Your changes have been saved')
-          redirect_to project_settings_operations_path(@project)
-        else
-          render 'show'
-        end
+        render_update_response(result)
       end
 
       private
 
+      # overridden in EE
+      def render_update_response(result)
+        respond_to do |format|
+          format.json do
+            render_update_json_response(result)
+          end
+        end
+      end
+
+      def render_update_json_response(result)
+        if result[:status] == :success
+          flash[:notice] = _('Your changes have been saved')
+          render json: {
+            status: result[:status]
+          }
+        else
+          render(
+            status: result[:http_status] || :bad_request,
+            json: {
+              status: result[:status],
+              message: result[:message]
+            }
+          )
+        end
+      end
+
       def error_tracking_setting
         @error_tracking_setting ||= project.error_tracking_setting ||
           project.build_error_tracking_setting
@@ -35,11 +55,14 @@ module Projects
 
       # overridden in EE
       def permitted_project_params
-        { error_tracking_setting_attributes: [:enabled, :api_url, :token] }
-      end
-
-      def check_license
-        render_404 unless helpers.settings_operations_available?
+        {
+          error_tracking_setting_attributes: [
+            :enabled,
+            :api_host,
+            :token,
+            project: [:slug, :name, :organization_slug, :organization_name]
+          ]
+        }
       end
     end
   end
