@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 module Ci
-  class Variable < ActiveRecord::Base
+  class Variable < ApplicationRecord
     extend Gitlab::Ci::Model
     include HasVariable
     include Presentable
