@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-class Timelog < ActiveRecord::Base
+class Timelog < ApplicationRecord
   validates :time_spent, :user, presence: true
   validate :issuable_id_is_present
 
