@@ -28,7 +28,12 @@ unless Sidekiq.server?
       }
 
       gitaly_calls = Gitlab::GitalyClient.get_request_count
-      payload[:gitaly_calls] = gitaly_calls if gitaly_calls > 0
+
+      if gitaly_calls > 0
+        payload[:gitaly_calls] = gitaly_calls
+        payload[:gitaly_duration] = Gitlab::GitalyClient.query_time_ms
+      end
+
       payload[:response] = event.payload[:response] if event.payload[:response]
       payload[Gitlab::CorrelationId::LOG_KEY] = Gitlab::CorrelationId.current_id
 
