@@ -20,6 +20,21 @@ def configure_sentry
       # Sanitize authentication headers
       config.sanitize_http_headers = %w[Authorization Private-Token]
       config.tags = { program: Gitlab.process_name }
+      # Debugging for https://gitlab.com/gitlab-org/gitlab-ce/issues/57727
+      config.before_send = lambda do |event, hint|
+        if ActiveModel::MissingAttributeError === hint[:exception]
+          columns_hash = ActiveRecord::Base
+                           .connection
+                           .schema_cache
+                           .instance_variable_get(:@columns_hash)
+                           .map { |k, v| [k, v.map(&:first)] }
+                           .to_h
+
+          event.extra.merge!(columns_hash)
+        end
+
+        event
+      end
     end
   end
 end
