@@ -33,12 +33,6 @@ module Gitlab
 
     MUTEX = Mutex.new
 
-    class << self
-      attr_accessor :query_time
-    end
-
-    self.query_time = 0
-
     define_histogram :gitaly_controller_action_duration_seconds do
       docstring "Gitaly endpoint histogram by controller and action combination"
       base_labels Gitlab::Metrics::Transaction::BASE_LABELS.merge(gitaly_service: nil, rpc: nil)
@@ -75,13 +69,11 @@ module Gitlab
 
       @certs = stub_cert_paths.flat_map do |cert_file|
         File.read(cert_file).scan(PEM_REGEX).map do |cert|
-          begin
-            OpenSSL::X509::Certificate.new(cert).to_pem
-          rescue OpenSSL::OpenSSLError => e
-            Rails.logger.error "Could not load certificate #{cert_file} #{e}"
-            Gitlab::Sentry.track_exception(e, extra: { cert_file: cert_file })
-            nil
-          end
+          OpenSSL::X509::Certificate.new(cert).to_pem
+        rescue OpenSSL::OpenSSLError => e
+          Rails.logger.error "Could not load certificate #{cert_file} #{e}"
+          Gitlab::Sentry.track_exception(e, extra: { cert_file: cert_file })
+          nil
         end.compact
       end.uniq.join("\n")
     end
@@ -176,6 +168,18 @@ module Gitlab
       add_call_details(feature: "#{service}##{rpc}", duration: duration, request: request_hash, rpc: rpc)
     end
 
+    def self.query_time
+      SafeRequestStore[:gitaly_query_time] ||= 0
+    end
+
+    def self.query_time=(duration)
+      SafeRequestStore[:gitaly_query_time] = duration
+    end
+
+    def self.query_time_ms
+      (self.query_time * 1000).round(2)
+    end
+
     def self.current_transaction_labels
       Gitlab::Metrics::Transaction.current&.labels || {}
     end
@@ -228,7 +232,7 @@ module Gitlab
       result
     end
 
-    SERVER_FEATURE_FLAGS = %w[go-find-all-tags].freeze
+    SERVER_FEATURE_FLAGS = %w[].freeze
 
     def self.server_feature_flags
       SERVER_FEATURE_FLAGS.map do |f|
@@ -257,8 +261,7 @@ module Gitlab
       # This is this actual number of times this call was made. Used for information purposes only
       actual_call_count = increment_call_count("gitaly_#{call_site}_actual")
 
-      # Do no enforce limits in production
-      return if Rails.env.production? || ENV["GITALY_DISABLE_REQUEST_LIMITS"]
+      return unless enforce_gitaly_request_limits?
 
       # Check if this call is nested within a allow_n_plus_1_calls
       # block and skip check if it is
@@ -275,6 +278,19 @@ module Gitlab
       raise TooManyInvocationsError.new(call_site, actual_call_count, max_call_count, max_stacks)
     end
 
+    def self.enforce_gitaly_request_limits?
+      # We typically don't want to enforce request limits in production
+      # However, we have some production-like test environments, i.e., ones
+      # where `Rails.env.production?` returns `true`. We do want to be able to
+      # check if the limit is being exceeded while testing in those environments
+      # In that case we can use a feature flag to indicate that we do want to
+      # enforce request limits.
+      return true if feature_enabled?('enforce_requests_limits')
+
+      !(Rails.env.production? || ENV["GITALY_DISABLE_REQUEST_LIMITS"])
+    end
+    private_class_method :enforce_gitaly_request_limits?
+
     def self.allow_n_plus_1_calls
       return yield unless Gitlab::SafeRequestStore.active?
 
@@ -286,6 +302,26 @@ module Gitlab
       end
     end
 
+    # Normally a FindCommit RPC will cache the commit with its SHA
+    # instead of a ref name, since it's possible the branch is mutated
+    # afterwards. However, for read-only requests that never mutate the
+    # branch, this method allows caching of the ref name directly.
+    def self.allow_ref_name_caching
+      return yield unless Gitlab::SafeRequestStore.active?
+      return yield if ref_name_caching_allowed?
+
+      begin
+        Gitlab::SafeRequestStore[:allow_ref_name_caching] = true
+        yield
+      ensure
+        Gitlab::SafeRequestStore[:allow_ref_name_caching] = false
+      end
+    end
+
+    def self.ref_name_caching_allowed?
+      Gitlab::SafeRequestStore[:allow_ref_name_caching]
+    end
+
     def self.get_call_count(key)
       Gitlab::SafeRequestStore[key] || 0
     end
