@@ -33,16 +33,6 @@ module Gitlab
         GitalyClient.call(storage, :object_pool_service, :link_repository_to_object_pool,
                           request, timeout: GitalyClient.fast_timeout)
       end
-
-      def unlink_repository(repository)
-        request = Gitaly::UnlinkRepositoryFromObjectPoolRequest.new(
-          object_pool: object_pool,
-          repository: repository.gitaly_repository
-        )
-
-        GitalyClient.call(storage, :object_pool_service, :unlink_repository_from_object_pool,
-                          request, timeout: GitalyClient.fast_timeout)
-      end
     end
   end
 end
