@@ -11,7 +11,9 @@ module Gitlab
     USERNAME_REGEXP = User.reference_pattern
 
     def initialize(text)
-      @text = text
+      # EE passes an Array to `text` in a few places, so we want to support both
+      # here.
+      @text = Array(text).join(' ')
     end
 
     def users
